==> gcc-g%2B%2B-4.0-20061005.tar.bz2: gcc-4.0-20061005/libstdc++-v3/testsuite/27_io/basic_filebuf/imbue/char/13171-2.cc <==
// { dg-require-fork "" }
// { dg-require-mkfifo "" }

// Copyright (C) 2003, 2005 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// 27.8.1.4 Overridden virtual functions

#include <fstream>
#include <locale>

#include <sys/types.h>
#include <sys/stat.h>

#include <testsuite_hooks.h>

// libstdc++/13171
void test01()
{
  bool test __attribute__((unused)) = true;
  using namespace std;
  using namespace __gnu_test;

  locale loc_fr(__gnu_test::try_named_locale("fr_FR"));
  locale loc_en(__gnu_test::try_named_locale("en_US"));

  const char* name = "tmp_fifo_13171-2";
  unlink(name);
  mkfifo(name, S_IRWXU);
  semaphore s1, s2;
  
  int child = fork();
  if (child == 0)
    {
      filebuf fb;
      fb.open(name, ios_base::out);
      fb.sputc('S');
      fb.pubsync();
      s1.signal ();
      s2.wait ();
      fb.close();
      exit(0);
    }

  filebuf fb;
  fb.pubimbue(loc_fr);
  fb.open(name, ios_base::in);
  s1.wait ();
  VERIFY( fb.is_open() );
  fb.pubimbue(loc_en);
  filebuf::int_type c = fb.sgetc();
  fb.close();
  VERIFY( c == 'S' );
  s2.signal ();
}

int main()
{
  test01();
  return 0;
}

==> gcc-g%2B%2B-4.1-20050716.tar.bz2: gcc-4.1-20050716/libstdc++-v3/testsuite/27_io/basic_filebuf/imbue/char/14975-1.cc <==
// { dg-require-namedlocale "" }

// 2004-04-16  Petur Runolfsson  <peturr02@ru.is>

// Copyright (C) 2004, 2005 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License along
// with this library; see the file COPYING.  If not, write to the Free
// Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307,
// USA.

// 27.8.1.4 Overridden virtual functions

#include <fstream>
#include <locale>
#include <testsuite_hooks.h>

class Buf : public std::filebuf
{
protected:
  virtual int_type
  overflow(int_type c = traits_type::eof())
  {
    return traits_type::eq_int_type(c, traits_type::eof()) ?
      traits_type::eof() : std::filebuf::overflow(c);
  }
};

// libstdc++/14975
void test01()
{
  using namespace std;
  bool test __attribute__((unused)) = true;

  Buf fb;
  locale loc_us = locale("en_US");
  fb.pubimbue(loc_us);
  fb.open("tmp_14975-1", ios_base::out);
  
  try
    {
      fb.sputc('a');
      fb.sputc('b');
      fb.pubimbue(locale::classic());
      fb.sputc('c');
      fb.pubsync();
      fb.close();
    }
  catch (std::exception&)
    {
    }
}

int main()
{
  test01();
  return 0;
}
